==> eclipseide-wild-web-developer-1.0.0-linux.gtk.aarch64.tar.gz: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_es_US.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_es_US extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "011", "\u00c1frica occidental" },
            { "014", "\u00c1frica oriental" },
            { "015", "\u00c1frica septentrional" },
            { "018", "\u00c1frica meridional" },
            { "030", "Asia oriental" },
            { "034", "Asia meridional" },
            { "035", "Sudeste asi\u00e1tico" },
            { "039", "Europa meridional" },
            { "145", "Asia occidental" },
            { "151", "Europa oriental" },
            { "154", "Europa septentrional" },
            { "155", "Europa occidental" },
            { "AC", "Isla de la Ascensi\u00f3n" },
            { "BA", "Bosnia y Herzegovina" },
            { "EH", "Sahara Occidental" },
            { "GG", "Guernsey" },
            { "QO", "Territorios alejados de Ocean\u00eda" },
            { "TA", "Trist\u00e1n de Acu\u00f1a" },
            { "UM", "Islas menores alejadas de EE. UU." },
            { "eu", "euskera" },
            { "gu", "gurayat\u00ed" },
            { "ht", "criollo haitiano" },
            { "lo", "lao" },
            { "nd", "ndebele del norte" },
            { "nr", "ndebele meridional" },
            { "rm", "romanche" },
            { "se", "sami del norte" },
            { "ss", "siswati" },
            { "st", "sesoto" },
            { "tn", "setchwana" },
            { "ace", "acehn\u00e9s" },
            { "alt", "alt\u00e1i meridional" },
            { "arp", "arapaho" },
            { "ars", "\u00e1rabe najdi" },
            { "bax", "bamun" },
            { "bho", "bhojpuri" },
            { "bla", "siksika" },
            { "bua", "buriat" },
            { "dum", "neerland\u00e9s medieval" },
            { "enm", "ingl\u00e9s medieval" },
            { "frm", "franc\u00e9s medieval" },
            { "gan", "gan (China)" },
            { "gmh", "alem\u00e1n de la alta edad media" },
            { "grc", "griego antiguo" },
            { "hil", "hiligain\u00f3n" },
            { "hsn", "xiang (China)" },
            { "inh", "ingusetio" },
            { "kab", "cabilio" },
            { "kbd", "kabardiano" },
            { "krc", "karachay-balkar" },
            { "lou", "creole de Luisiana" },
            { "lrc", "lor\u00ed del norte" },
            { "lus", "lushai" },
            { "mga", "irland\u00e9s medieval" },
            { "nso", "sotho septentrional" },
            { "shu", "\u00e1rabe chadiano" },
            { "sma", "sami meridional" },
            { "smn", "sami de Inari" },
            { "syr", "siriaco" },
            { "tet", "tet\u00fan" },
            { "tyv", "tuviniano" },
            { "tzm", "tamazight del Marruecos Central" },
            { "xal", "kalmyk" },
            { "Hrkt", "silabarios del japon\u00e9s" },
            { "Zzzz", "letra desconocida" },
            { "sw_CD", "swahili del Congo" },
            { "type.nu.gujr", "d\u00edgitos en gujarati" },
        };
        return data;
    }
}

==> eclipseide-wild-web-developer-1.3.1-linux.gtk.aarch64.tar.gz: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_es_US.java <==
/*
 * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_es_US extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "011", "\u00c1frica occidental" },
            { "014", "\u00c1frica oriental" },
            { "015", "\u00c1frica septentrional" },
            { "018", "\u00c1frica meridional" },
            { "030", "Asia oriental" },
            { "034", "Asia meridional" },
            { "035", "Sudeste asi\u00e1tico" },
            { "039", "Europa meridional" },
            { "145", "Asia occidental" },
            { "151", "Europa oriental" },
            { "154", "Europa septentrional" },
            { "155", "Europa occidental" },
            { "AC", "Isla de la Ascensi\u00f3n" },
            { "BA", "Bosnia y Herzegovina" },
            { "EH", "Sahara Occidental" },
            { "GG", "Guernsey" },
            { "QO", "Territorios alejados de Ocean\u00eda" },
            { "TA", "Trist\u00e1n de Acu\u00f1a" },
            { "UM", "Islas menores alejadas de EE. UU." },
            { "eu", "euskera" },
            { "gu", "gurayat\u00ed" },
            { "ht", "criollo haitiano" },
            { "lo", "lao" },
            { "nd", "ndebele del norte" },
            { "nr", "ndebele meridional" },
            { "rm", "romanche" },
            { "se", "sami del norte" },
            { "ss", "siswati" },
            { "ace", "acehn\u00e9s" },
            { "alt", "alt\u00e1i meridional" },
            { "arp", "arapaho" },
            { "ars", "\u00e1rabe najdi" },
            { "bax", "bamun" },
            { "bho", "bhojpuri" },
            { "bla", "siksika" },
            { "bua", "buriat" },
            { "clc", "chilcot\u00edn" },
            { "crj", "cree del sureste" },
            { "crl", "cree del noreste" },
            { "crm", "moose cree" },
            { "crr", "algonquian" },
            { "dum", "neerland\u00e9s medieval" },
            { "enm", "ingl\u00e9s medieval" },
            { "frm", "franc\u00e9s medieval" },
            { "gan", "gan (China)" },
            { "gmh", "alem\u00e1n de la alta edad media" },
            { "grc", "griego antiguo" },
            { "hax", "haida del sur" },
            { "hil", "hiligain\u00f3n" },
            { "hsn", "xiang (China)" },
            { "ikt", "inuktitut del oeste de Canad\u00e1" },
            { "inh", "ingusetio" },
            { "kab", "cabilio" },
            { "krc", "karachay-balkar" },
            { "lou", "creole de Luisiana" },
            { "lrc", "lor\u00ed del norte" },
            { "lsm", "saamia" },
            { "mga", "irland\u00e9s medieval" },
            { "ojb", "ojibwa del noroeste" },
            { "ojw", "ojibwa del oeste" },
            { "pis", "pij\u00edn" },
            { "shu", "\u00e1rabe chadiano" },
            { "slh", "lushootseed del sur" },
            { "sma", "sami meridional" },
            { "smn", "sami de Inari" },
            { "str", "straits salish" },
            { "syr", "siriaco" },
            { "tce", "tutchone del sur" },
            { "tet", "tet\u00fan" },
            { "ttm", "tutchone del norte" },
            { "tyv", "tuviniano" },
            { "wal", "wolayta" },
            { "Adlm", "adlam" },
            { "Hrkt", "silabarios del japon\u00e9s" },
            { "Rohg", "hanaf\u00ed" },
            { "Zzzz", "letra desconocida" },
            { "sw_CD", "swahili del Congo" },
            { "type.nu.cakm", "d\u00edgitos chakma" },
            { "type.nu.gujr", "d\u00edgitos en gujarati" },
            { "type.nu.java", "d\u00edgitos javaneses" },
            { "type.nu.mtei", "d\u00edgitos meetei mayek" },
            { "type.nu.olck", "d\u00edgitos ol chiki" },
        };
        return data;
    }
}
